/*
* Author: SpicePress
* Created by: Shahid (Scientech IT)
* Copyright (c) 2017 SpicePress
* Date: 1 Dec, 2017
* http://www.spicethemes.com
* Name: default.css
*/


/*===================================================================================*/
/*  MENUBAR SECTION
/*===================================================================================*/

.navbar-custom .navbar-nav > li > a:focus,
.navbar-custom .navbar-nav > li > a:hover,
.navbar-custom .navbar-nav .open > a,
.navbar-custom .navbar-nav .open > a:focus,
.navbar-custom .navbar-nav .open > a:hover {
    color: #ce1b28;
    background-color: transparent;
}
.navbar-custom .navbar-nav > .active > a,
.navbar-custom .navbar-nav > .active > a:hover,
.navbar-custom .navbar-nav > .active > a:focus {
    color: #ffffff;
    background-color: #ce1b28;
}
.navbar-custom .dropdown-menu {
    border-top: 2px solid #ce1b28;
    border-bottom: 2px solid #ce1b28;
}
.navbar-custom .navbar-nav .open .dropdown-menu > .active > a,
.navbar-custom .navbar-nav .open .dropdown-menu > .active > a:hover,
.navbar-custom .navbar-nav .open .dropdown-menu > .active > a:focus {
    background-color: transparent;
    color: #ce1b28;
}


/*Dropdown Menus & Submenus Css----------------------------------------------------------*/

.navbar-custom .dropdown-menu {
    border-top: 2px solid #ce1b28;
    border-bottom: 2px solid #ce1b28;
}

/*===================================================================================*/
/*  CART ICON
/*===================================================================================*/

.cart-header:hover > a { color: #ce1b28; }
.cart-header > a .cart-total { background: #ce1b28; }


/*===================================================================================*/
/*  HOMEPAGE SLIDER
/*===================================================================================*/

.slide-btn-sm:before, .slide-btn-sm:after { background-color: #ce1b28; }
/*Status Format*/
.format-status-btn-sm { background-color: #ce1b28; box-shadow: 0 3px 0 0 #b3131f; }

/*Video Format*/
.format-video-btn-sm { background-color: #ce1b28; box-shadow: 0 3px 0 0 #b3131f; }
/* Direction Nav */
.slide-shadow { background: url("../images/slide-shadow.png") no-repeat center bottom #fff; }



/*===================================================================================*/
/*  SECTION HEADER
/*===================================================================================*/

.widget-separator span { background-color: #ce1b28; }

/*===================================================================================*/
/*  SECRVICE SECTION
/*===================================================================================*/

.service-section .post:hover { border-top: 3px solid #ce1b28; }
.txt-pink { color: #ce1b28; }
.more-link, .more-link:hover, .more-link:focus { color: #ce1b28; }

/*===================================================================================*/
/*  PORTFOLIO SECTION
/*===================================================================================*/

/*Portfolio Tabs*/
.portfolio-tabs li.active > a, .portfolio-tabs li > a:hover { border-color: #ce1b28; background: #ce1b28; }


/*===================================================================================*/
/*  TESTIMONIAL SECTION
/*===================================================================================*/

.author-description p:before { color: #ce1b28; }

/*===================================================================================*/
/*  CALLOUT SECTION
/*===================================================================================*/

.sm-callout { border-top: 2px solid #ce1b28; }
.sm-callout-btn a { background-color: #ce1b28; box-shadow: 0 3px 0 0 #b3131f; }
.sm-callout-btn a:hover { color: #ffffff; }

/*===================================================================================*/
/*  PAGE TITLE SECTION
/*===================================================================================*/

.page-title-section .overlay { background-color: #ce1b28; }

/*===================================================================================*/
/*  ABOUT US PAGE
/*===================================================================================*/

.about-section h2 > span { color: #ce1b28; }

/*===================================================================================*/
/*  TEAM SECTION
/*===================================================================================*/

.team-image .team-showcase-icons a:hover { background-color: #ce1b28; }

/*===================================================================================*/
/*  HOMEPAGE BLOG & BLOG PAGE SECTION
/*===================================================================================*/

/*Entry Title*/
.entry-header .entry-title > a:hover, .entry-header .entry-title > a:focus { color: #ce1b28; }
/*Blog Meta*/
.entry-meta a:hover, .entry-meta a:focus { color: #ce1b28; }
.entry-meta .entry-date > a { background-color: #ce1b28; }
/*More Link*/
.home-news .more-link:hover, .home-news .more-link:focus,
.blog-section .more-link:hover, .blog-section .more-link:focus {
    background-color: transparent;
    color: #ce1b28 !important;
}
/*Comment Section*/
.comment-date { color: #ce1b28; }
.reply a { background-color: #ce1b28; box-shadow: 0 3px 0 0 #b3131f; }
.blogdetail-btn, .blogdetail-btn a { background-color: #ce1b28; box-shadow: 0 3px 0 0 #b3131f; }

/*===================================================================================*/
/*  SIDEBAR SECTION
/*===================================================================================*/

/*Sidebar Calender Widget*/
.widget table#wp-calendar caption { background-color: #ce1b28; }
.widget table#wp-calendar a:hover, .widget table#wp-calendar a:focus,
.widget table#wp-calendar #next a:hover, .widget table#wp-calendar #next a:focus,
.widget table#wp-calendar #prev a:hover, .widget table#wp-calendar #prev a:focus { color: #ce1b28; }
/*Sidebar Widget Archive, Widget categories, Widget Links, Widget Meta, widget Nav Menu, Widget Pages, Widget Recent Comments, Widget Recent Entries */
.widget_archive a:hover, .widget_categories a:hover, .widget_links a:hover,
.widget_meta a:hover, .widget_nav_menu a:hover, .widget_pages a:hover,
.widget_recent_comments a:hover, .widget_recent_entries a:hover {
    color: #ce1b28 !important;
}
.widget_archive li:before, .widget_categories li:before, .widget_links li:before,
.widget_meta li:before, .widget_nav_menu li:before, .widget_pages li:before,
.widget_recent_comments li:before, .widget_recent_entries li:before {
    color: #ce1b28;
}
/*Sidebar Search*/
form.search-form input.search-submit,
input[type="submit"],
.woocommerce-product-search input[type="submit"], .home-blog-btn, .widget button[type="submit"] { background-color: #ce1b28; }

/*Sidebar Tags*/
.tagcloud a:hover { background-color: #ce1b28; border: 1px solid #ce1b28; }

/*===================================================================================*/
/*  HEADER SIDEBAR & FOOTER SIDEBAR SECTION
/*===================================================================================*/

.site-footer { border-top: 3px solid #ce1b28; border-bottom: 3px solid #ce1b28; }
.header-sidebar .section-header span, .footer-sidebar .section-header span { background-color: #ce1b28; }
/*Sidebar Latest Post Widget*/
.footer-sidebar .widget .post .entry-title:hover, .footer-sidebar .widget .post .entry-title a:hover,
.header-sidebar .widget .post .entry-title:hover, .header-sidebar .widget .post .entry-title a:hover {
    color: #ce1b28;
}
.widget .post:hover .entry-title a { color: #ce1b28; }

/*===================================================================================*/
/*  FOOTER COPYRIGHTS - SITE INFO
/*===================================================================================*/

.site-info a:hover, .site-info a:focus { color: #ce1b28; }

/*===================================================================================*/
/*  WP THEME DATA - CUSTOM HTML TAGS
/*===================================================================================*/
blockquote { border-left: 5px solid #ce1b28; }
table a, table a:hover, table a:focus,
a, a:hover, a:focus,
dl dd a, dl dd a:hover, dl dd a:focus { color: #ce1b28; }
p > mark, p > ins { background-color: #ce1b28; }

/*===================================================================================*/
/*  CONTACT SECTION
/*===================================================================================*/

.cont-info address > a:hover, .cont-info address > a:focus { color: #ce1b28; }

/*===================================================================================*/
/*  404 ERROR PAGE SECTION
/*===================================================================================*/

.error_404 h1 { color: #ce1b28; }
.error_404 p > a { color: #ce1b28; }

/*===================================================================================*/
/*  SCROLL BUTTON PAGE TO TOP
/*===================================================================================*/

.hc_scrollup { background-color: #ce1b28; }


/*WOOCOMMERCE CSS-----------------------------------------------------------------------------------------------------------------*/
/* Woocommerce Colors-------------------------------------------------------------------------------------------- */
.woocommerce ul.products li.product .price del, .woocommerce ul.products li.product .price ins, .woocommerce div.product p.price ins, .woocommerce ul.products li.product .price, .woocommerce .variations td.label, .woocommerce table.shop_table td, .woocommerce-cart .cart-collaterals .cart_totals table td, .woocommerce .woocommerce-ordering select, .woocommerce-cart table.cart td.actions .coupon .input-text, .select2-container .select2-choice { color: #64646d; }
.woocommerce div.product p.price, .woocommerce div.product span.price, .woocommerce .posted_in a, .woocommerce-product-rating a, .woocommerce .tagged_as a, .woocommerce div.product form.cart .variations td.label label, .woocommerce #reviews #comments ol.commentlist li .meta strong, .woocommerce table.shop_table th, .woocommerce-cart table.cart td a, .woocommerce ul.cart_list li a, .woocommerce ul.product_list_widget li a, .woocommerce-error, .woocommerce-info, .woocommerce-message { color: #0f0f16; }
.woocommerce ul.products li.product .button { color: #fff; }
.woocommerce ul.product_list_widget li a:hover, .woocommerce ul.product_list_widget li a:focus,
.woocommerce .posted_in a:hover, .woocommerce .posted_in a:focus { color: #ce1b28; }
.woocommerce ul.products li.product:hover .button,
.woocommerce ul.products li.product:focus .button,
.woocommerce div.product form.cart .button:hover,
.woocommerce div.product form.cart .button:focus,
.woocommerce div.product form.cart .button, .woocommerce a.button, .woocommerce a.button:hover, .woocommerce input.button:disabled, .woocommerce input.button:disabled[disabled], .woocommerce-EditAccountForm input.woocommerce-Button, #add_payment_method table.cart img, .woocommerce-cart table.cart img, .woocommerce-checkout table.cart img { border: 4px double #e9e9e9; }
.woocommerce div.product form.cart .button, .woocommerce a.button, .woocommerce a.button:hover, .woocommerce a.added_to_cart, .woocommerce table.my_account_orders .order-actions .button { color: #fff; }
.woocommerce ul.products li.product .button { background: #ce1b28 !important; }
.woocommerce ul.products li.product .button, .woocommerce ul.products li.product .button:hover { border: 1px solid #ce1b28 !important; }
.woocommerce ul.products li.product,
.woocommerce-page ul.products li.product { background-color: #ffffff; border: 1px solid #e9e9e9; }
.woocommerce #respond input#submit.alt, .woocommerce a.button.alt, .woocommerce button.button.alt, .woocommerce input.button.alt, .woocommerce button.button.alt.disabled, .woocommerce button.button.alt.disabled:hover { background-color: #ce1b28; }
.woocommerce #respond input#submit.alt:hover, .woocommerce a.button.alt:hover, .woocommerce button.button.alt:hover, .woocommerce input.button.alt:hover {
    background-color: #ce1b28;
    color: #fff;
}
.woocommerce .star-rating span { color: #ce1b28; }
.woocommerce ul.products li.product .onsale, .woocommerce span.onsale { background: #ce1b28; border: 2px solid #ce1b28; color: #fff; }
.woocommerce ul.products li.product:hover .onsale, .woocommerce mark, .woocommerce ins { color: #fff; }
.woocommerce span.onsale:hover { color: #fff; }
.woocommerce ul.products li.product:before, .woocommerce ul.products li.product:after, .woocommerce-page ul.products li.product:before, .woocommerce-page ul.products li.product:after {
    content: "";
    position: absolute;
    z-index: -1;
    top: 50%;
    bottom: 0;
    left: 10px;
    right: 10px;
    -moz-border-radius: 100px / 10px;
    border-radius: 100px / 10px;
}
.woocommerce ul.products li.product:before, .woocommerce ul.products li.product:after, .woocommerce-page ul.products li.product:before, .woocommerce-page ul.products li.product:after {
    -webkit-box-shadow: 0 0 15px rgba(0,0,0,0.8);
    -moz-box-shadow: 0 0 15px rgba(0,0,0,0.8);
    box-shadow: 0 0 15px rgba(0,0,0,0.8);
}
.woocommerce a.remove, .woocommerce .woocommerce-Button, .woocommerce .cart input.button, .woocommerce input.button.alt, .woocommerce button.button, .woocommerce #respond input#submit, .woocommerce .cart input.button:hover,
.woocommerce .cart input.button:focus,
.woocommerce input.button.alt:hover,
.woocommerce input.button.alt:focus,
.woocommerce input.button:hover,
.woocommerce input.button:focus,
.woocommerce button.button:hover,
.woocommerce button.button:focus,
.woocommerce #respond input#submit:hover,
.woocommerce #respond input#submit:focus,
.woocommerce ul.products li.product:hover .button,
.woocommerce-cart .wc-proceed-to-checkout a.checkout-button, .woocommerce .return-to-shop a.button, .woocommerce-mini-cart__buttons a.button  { color: #ffffff !important; }
.woocommerce div.product form.cart .button, .woocommerce a.button, .woocommerce a.button:hover, .woocommerce a.button, .woocommerce .woocommerce-Button, .woocommerce .cart input.button, .woocommerce input.button.alt, .woocommerce button.button, .woocommerce #respond input#submit, .woocommerce .cart input.button:hover, .woocommerce .cart input.button:focus,
.woocommerce input.button.alt:hover, .woocommerce input.button.alt:focus,
.woocommerce input.button:hover, .woocommerce input.button:focus,
.woocommerce button.button:hover, .woocommerce button.button:focus,
.woocommerce #respond input#submit:hover, .woocommerce #respond input#submit:focus,
.woocommerce-cart .wc-proceed-to-checkout a.checkout-button { background: #ce1b28; border: 1px solid transparent !important; }
.woocommerce-message, .woocommerce-info {
    border-top-color: #ce1b28;
}
.woocommerce-message::before, .woocommerce-info::before { color: #ce1b28; }
.woocommerce div.product div.summary {
    margin-bottom: 2em;
    padding: 0.4rem 0.9rem 1.5rem;
    background-color: #fff;
    border: 1px solid #e9e9e9;
}
.price_label { color: #727272; }
.woocommerce a.added_to_cart { background: #21202e; border: 1px solid #ffffff; }
.woocommerce a.button { border-radius: 0px; box-shadow: none; }
.woocommerce #reviews #comments ol.commentlist li .comment-text { border: 1px solid #e4e1e3; }
.woocommerce #reviews #comments ol.commentlist li .meta time { color: #8f969c; }
.woocommerce #review_form #respond textarea, .woocommerce-cart table.cart td.actions .coupon .input-text { border: 1px solid #e9e9e9; }
.woocommerce-error, .woocommerce-info, .woocommerce-message { background-color: #fbfbfb; box-shadow: 0 7px 3px -5px #e0e0e0; }
.woocommerce table.shop_table, .woocommerce table.shop_table td { border: 1px solid rgba(0, 0, 0, .1); }
.woocommerce table.shop_table th { background-color: #fbfbfb; }
#add_payment_method table.cart img, .woocommerce-cart table.cart img, .woocommerce-checkout table.cart img { border: 4px double #e9e9e9; }
.woocommerce a.remove { background: #555555; }
.woocommerce .checkout_coupon input.button,
.woocommerce .woocommerce-MyAccount-content input.button, .woocommerce .login input.button { background-color: #ce1b28; color: #ffffff; border: 1px solid transparent; }
.woocommerce-page #payment #place_order { border: 1px solid transparent; }
.select2-container .select2-choice, .select2-drop-active, .woocommerce .woocommerce-ordering select, .woocommerce .widget select {
    border: 1px solid #e9e9e9;
}
.woocommerce-checkout #payment ul.payment_methods { background-color: #fbfbfb; border: 1px solid rgba(0, 0, 0, .1); }
#add_payment_method #payment div.payment_box, .woocommerce-cart #payment div.payment_box, .woocommerce-checkout #payment div.payment_box { background-color: #ebe9eb; }
#add_payment_method #payment div.payment_box:before,
.woocommerce-cart #payment div.payment_box:before,
.woocommerce-checkout #payment div.payment_box:before {
    border: 1em solid #ebe9eb;
    border-right-color: transparent;
    border-left-color: transparent;
    border-top-color: transparent;
}
.woocommerce nav.woocommerce-pagination ul li a,
.woocommerce nav.woocommerce-pagination ul li span { background-color: transparent; border: 1px solid #0f0f16; color: #242526; }
.woocommerce nav.woocommerce-pagination ul li a:focus, .woocommerce nav.woocommerce-pagination ul li a:hover, .woocommerce nav.woocommerce-pagination ul li span.current { background-color: #0f0f16; border: 1px solid #0f0f16; color: #ffffff; }
.woocommerce-MyAccount-navigation ul li { border-bottom: 1px solid #ebe9eb; }
.woocommerce-EditAccountForm input.woocommerce-Button { border: 1px solid #ffffff; }
.ui-slider .ui-slider-handle {
    border: 1px solid rgba(0, 0, 0, 0.25);
    background: #e7e7e7;
    background: -webkit-gradient(linear,left top,left bottom,from(#FEFEFE),to(#e7e7e7));
    background: -webkit-linear-gradient(#FEFEFE,#e7e7e7);
    background: -moz-linear-gradient(center top,#FEFEFE 0%,#e7e7e7 100%);
    background: -moz-gradient(center top,#FEFEFE 0%,#e7e7e7 100%);
    -webkit-box-shadow: 0 1px 2px rgba(0, 0, 0, 0.3), 0 0 0 1px rgba(255, 255, 255, 0.65) inset;
    -moz-box-shadow: 0 1px 2px rgba(0, 0, 0, 0.3), 0 0 0 1px rgba(255, 255, 255, 0.65) inset;
    box-shadow: 0 1px 2px rgba(0, 0, 0, 0.3), 0 0 0 1px rgba(255, 255, 255, 0.65) inset;
}
.price_slider_wrapper .ui-widget-content {
    background: #1e1e1e;
    background: -webkit-gradient(linear,left top,left bottom,from(#1e1e1e),to(#6a6a6a));
    background: -webkit-linear-gradient(#1e1e1e,#6a6a6a);
    background: -moz-linear-gradient(center top,#1e1e1e 0%,#6a6a6a 100%);
    background: -moz-gradient(center top,#1e1e1e 0%,#6a6a6a 100%);
}
.sidebar-widget .widget-title { border-bottom: 2px solid #eeeeee; }
.sidebar-widget .woocommerce ul.cart_list li { border-bottom: 1px dotted #d1d1d1; }
.woocommerce div.product .woocommerce-tabs .panel { background: #fff; border: 1px solid #e9e9e9; }
.woocommerce .widget_price_filter .ui-slider .ui-slider-range { background-color: #ce1b28; }

/*===================================================================================*/
/*  WOOCOMMERCE PRODUCT CAROUSEL
/*===================================================================================*/

.product_container { background-color: #ffffff; border: 1px solid #e9e9e9; }
.testimonial-section .wpcs_product_carousel_slider .title, .top-header-detail .wpcs_product_carousel_slider .title { color: #ffffff !important; }

/*Woocommerce Section----------------------------------------------------------------------------------------*/
.woocommerce-section {  background-color: #ce1b28; }
.rating li i { color: #ce1b28; }
.products .onsale { background: #ce1b28; border: 2px solid #ce1b28; }

/*404 */
.error_404_btn:hover, .error_404_btn:focus {
   background-color: #ce1b28;
}

.error_404_btn {
   background-color: transparent;
   color: #ce1b28;
   border: 1px solid #ce1b28;
}
/*===================================================================================*/
/*	24.0 Widget Classes
/*===================================================================================*/
.sidebar .wp-block-search .wp-block-search__label,.sidebar .widget.widget_block h1,.sidebar .widget.widget_block h2,.sidebar .widget.widget_block h3,.sidebar .widget.widget_block h4,.sidebar .widget.widget_block h5,.sidebar .widget.widget_block h6, .sidebar .widget.widget_block .wc-block-product-search__label{
    border-left: 5px solid #ce1b28;
}
.widget li:before {
    color: #ce1b28;
}
.wp-block-tag-cloud a:hover {
    background-color: #ce1b28;
    border: 1px solid #ce1b28;
}
.footer-sidebar .wp-block-page-list a:hover{
    color: #ce1b28;
}
.footer-sidebar .wp-block-search__label:after,.footer-sidebar .widget_block h1:after, .footer-sidebar .widget_block h2:after,.footer-sidebar .widget_block h3:after,.footer-sidebar .widget_block h4:after,.footer-sidebar .widget_block h5:after,.footer-sidebar .widget_block h6:after{
    background-color: #ce1b28;
}
.sidebar li a:hover{
color: #ce1b28 !important;
}
.footer-sidebar .widget li a{color: #9595a0;}
.footer-sidebar .widget li a:hover{color: #ce1b28;}

.rtl .sidebar .wp-block-search .wp-block-search__label, .rtl .sidebar .widget.widget_block h1, .rtl .sidebar .widget.widget_block h2, .rtl .sidebar .widget.widget_block h3, .rtl .sidebar .widget.widget_block h4, .rtl .sidebar .widget.widget_block h5, .rtl .sidebar .widget.widget_block h6, .rtl .sidebar .widget.widget_block .wc-block-product-search__label{
    border-right: 5px solid #ce1b28;
    border-left: none;
}
/*===================================================================================*/
/*  25.0 Post Navigation
/*===================================================================================*/
.post .edit-link a:hover,.post .nav-title:hover,.post a:hover .nav-subtitle{color: #ce1b28;}

body a{color: #ce1b28;}